<!--
 * @Descripttion:
 * @version:
 * @Author: kBank
 * @Date: 2022-10-24 15:45:01
-->
<template>
  <div class="page">
    <topBar
      v-if="topList.length > 0"
      :topList="topList"
      :moren="moren"
    ></topBar>
    <div class="main">
      <div class="form_all">
        <el-form ref="select" :model="select" label-width="auto">
          <el-row :gutter="10">
            <!-- <el-col :span="4">
              <el-form-item label="调出人">
                <el-input clearable
                          v-model="select.pkDept"></el-input>
              </el-form-item>
            </el-col> -->
            <!-- <el-col :span="4">
              <el-form-item label="调出人">
                <el-select clearable
                           v-model="select.pkWhsmanager"
                           :placeholder="'请选择'">
                  <el-option v-for="(item, index) in userAllList"
                             :key="index"
                             :label="item.nickName"
                             :value="item.userId"></el-option>
                </el-select>
              </el-form-item>
            </el-col> -->
            <el-col :span="4">
              <el-form-item label="订单编号">
                <el-input clearable v-model="select.orderCode"></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="4">
              <el-form-item label="调出公司" prop="pkCorp">
                <el-select
                  clearable
                  v-model="select.pkCorp"
                  :placeholder="'请选择'"
                >
                  <el-option
                    v-for="(item, index) in corpList"
                    :key="index"
                    :label="item.corpName"
                    :value="item.pkId"
                  ></el-option>
                </el-select>
              </el-form-item>
            </el-col>
            <el-col :span="4">
              <el-form-item :label="'订单状态'">
                <el-select
                  clearable
                  v-model="select.orderStatus"
                  :placeholder="'请选择'"
                >
                  <el-option
                    v-for="(item, index) in orderStatusList"
                    :key="index"
                    :label="item.label"
                    :value="item.value"
                  ></el-option>
                </el-select>
              </el-form-item>
            </el-col>
            <el-col :span="4">
              <el-form-item label="产品名称">
                <el-input clearable v-model="select.productName"></el-input>
              </el-form-item>
            </el-col>
            <!-- <el-col :span="4">
              <el-form-item label="调拨方式">
              <el-select clearable
                         v-model="select.transType"
                         :placeholder="'请选择'">
                <el-option v-for="(item, index) in transList"
                           :key="index"
                           :label="item.label"
                           :value="item.value"></el-option>
              </el-select>
              </el-form-item>
            </el-col> -->
            <el-col :span="6">
              <el-form-item label="订单日期">
                <el-date-picker
                  v-model="orderDate"
                  @change="getTime"
                  value-format="yyyy-MM-dd"
                  type="daterange"
                >
                </el-date-picker>
              </el-form-item>
            </el-col>
            <!-- <el-col :span="4">
              <el-form-item label="调入国家">
                <el-select clearable
                           v-model="select.pkInCountry"
                           :placeholder="'请选择'">
                  <el-option v-for="(item, index) in countryList"
                             :key="index"
                             :label="item.shortName"
                             :value="item.pkId"></el-option>
                </el-select>
              </el-form-item>
            </el-col> -->
            <!-- <el-col :span="4">
              <el-form-item label="供应商">
                <el-select clearable
                           v-model="select.pkCubasdoc"
                           :placeholder="'请选择'">
                  <el-option v-for="(item, index) in supplierList"
                             :key="index"
                             :label="item.custName"
                             :value="item.pkId"></el-option>
                </el-select>
              </el-form-item>
            </el-col> -->
            <el-col :span="4">
              <el-button type="primary" @click="getDataList">
                {{ '搜索' }}</el-button
              >
              <el-button type="" @click="reset"> {{ '重置' }}</el-button>
            </el-col>
          </el-row>
        </el-form>
      </div>
      <div class="maintop">
        <div class="mainbtn">
          <el-button
            size="small"
            @click="openDig"
            v-hasButtons="['InOrOutAdd']"
            class="addBtn"
            >{{ '添加' }}</el-button
          >
          <el-button
            size="small"
            :disabled="selRow.length == 0 || selRow.length > 1"
            @click="goQc"
            v-hasButtons="['InOrOutUp']"
            type="success"
            >{{ '提交' }}</el-button
          >
        </div>
      </div>
      <div class="maintable">
        <el-table
          :data="tableData"
          v-loading="loading"
          style="width: 100%"
          height="350px"
          :header-cell-style="{ background: '#EEEEEE' }"
          :row-class-name="tableRowClassName"
          @row-click="selectRow"
          @selection-change="handleSelectionChange"
        >
          <el-table-column type="selection" width="55"> </el-table-column>
          <el-table-column
            align="center"
            prop="orderCode"
            :label="'订单编号'"
          >
          </el-table-column>

          <el-table-column align="center" prop="corpName" label="调出公司">
          </el-table-column>
          <el-table-column align="center" prop="deptName" label="调出部门">
          </el-table-column>
          <el-table-column align="center" prop="managerName" label="调出人">
          </el-table-column>
          <el-table-column align="center" prop="transTypeVal" label="调拨方式">
          </el-table-column>
          <el-table-column align="center" prop="countryInName" label="调入国家">
          </el-table-column>
          <el-table-column align="center" prop="corpInName" label="调入公司">
          </el-table-column>
          <el-table-column align="center" prop="totalNum" label="总数量">
          </el-table-column>
          <el-table-column align="center" prop="totalOrigmny" label="价税合计">
          </el-table-column>
          <el-table-column
            align="center"
            prop="orderStatusVal"
            label="订单状态"
          >
          </el-table-column>
          <el-table-column
            align="center"
            prop="printStatusVal"
            label="打印状态"
          >
          </el-table-column>
          <el-table-column align="center" prop="remark" label="备注">
          </el-table-column>
          <el-table-column align="center" prop="orderDate" label="订单日期">
          </el-table-column>
          <el-table-column
            align="center"
            prop="time"
            width="150"
            :label="'操作'"
            fixed="right"
          >
            <template slot-scope="scope">
              <el-button
                @click="toFixed(scope.row)"
                type="text"
                v-if="scope.row.orderStatus == 1"
                v-hasButtons="['InOrOutEdit']"
                style="color: #f3a900"
                size="small"
              >
                {{ '修改' }}
              </el-button>
              <el-button
                @click="handleDelete(scope.row.pkId)"
                type="text"
                v-hasButtons="['InOrOutDel']"
                size="small"
                v-if="scope.row.orderStatus == 1"
                style="color: #c8161d"
              >
                {{ '删除' }}
              </el-button>
            </template>
          </el-table-column>
        </el-table>
      </div>
      <div class="maintable">
        <el-table
          :data="tableDataDetails"
          v-loading="loading2"
          style="width: 100%"
          height="350px"
          :header-cell-style="{ background: '#EEEEEE' }"
          :row-class-name="tableRowClassName"
          @selection-change="handleSelectionChange1"
        >
          <!-- <el-table-column type="selection"
                           width="55"> </el-table-column> -->
          <el-table-column align="center" prop="productCode" label="产品编号">
          </el-table-column>

          <el-table-column align="center" prop="productName" label="产品名称">
          </el-table-column>
          <el-table-column align="center" prop="specsName" label="产品规格">
          </el-table-column>
          <el-table-column align="center" prop="unitName" label="单位">
          </el-table-column>
          <el-table-column align="center" prop="cubasdocName" label="供应商">
          </el-table-column>
          <!-- <el-table-column align="center"
                           prop="nnum"
                           label="客户">
          </el-table-column> -->
          <!-- <el-table-column align="center"
                           prop="pkInCountry"
                           label="调入国家">
          </el-table-column>
          <el-table-column align="center"
                           prop="pkInCorp"
                           label="调入公司">
          </el-table-column> -->
          <el-table-column
            align="center"
            prop="inStorehouseName"
            label="调入仓库"
          >
          </el-table-column>
          <!-- <el-table-column align="center"
                           prop="pkCorp"
                           label="调出公司">
          </el-table-column> -->
          <el-table-column
            align="center"
            prop="storehouseName"
            label="调出仓库"
          >
          </el-table-column>
          <el-table-column align="center" prop="nnum" label="数量">
          </el-table-column>
          <el-table-column align="center" prop="norigprice" label="无税单价">
          </el-table-column>
          <el-table-column align="center" prop="ntaxrate" label="税率">
          </el-table-column>
          <el-table-column align="center" prop="norigtaxprice" label="含税单价">
          </el-table-column>
          <el-table-column align="center" prop="norigmny" label="无税金额">
          </el-table-column>
          <el-table-column align="center" prop="ntax" label="税额">
          </el-table-column>
          <el-table-column align="center" prop="norigtaxmny" label="价税合计">
          </el-table-column>
          <el-table-column
            align="center"
            prop="totalTransOutNum"
            label="累计调拨出库数量"
          >
          </el-table-column>
          <el-table-column
            align="center"
            prop="totalTransInNum"
            label="累计调拨入库数量"
          >
          </el-table-column>
          <!-- <el-table-column align="center"
                           prop="closeDate"
                           label="是否出库">
          </el-table-column> -->
          <el-table-column align="center" prop="batchCode" label="批次号">
          </el-table-column>
          <el-table-column align="center" prop="planDate" label="计划出库时间">
          </el-table-column>
        </el-table>
      </div>
    </div>
    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getDataList"
    />
  </div>
</template>

<script>
import topBar from "@/components/topBar";
import * as api from "@/api/supply.js";
import * as man from "@/api/manage";

export default {
  name: "Bzpz",
  components: {
    topBar,
  },
  data() {
    return {
      select: {},
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 50,
      },
      addOrEdit: "",
      total: 0,
      dialogVisible: false,
      tableData: [],
      loading: false,
      tableDataDetails: [],
      loading2:false,
      supplierList: [],
      countryList: [],
      transList: [],
      moren: "inOrOut",
      topList: [
        {
          name: "调拨订单",
          path: "inOrOut",
        },
      ],
      selRow: [],
      orderDate: [],
      orderStatusList: [],
      corpList: [],
    };
  },
  mounted() {
    // 获取列表
    this.getDataList();
    this.getData();
  },
  methods: {
    goQc() {
      this.$router.push({
        path: "inOrOutZxqc",
        query: {
          data: JSON.stringify(this.selRow[0]),
          index: 804,
        },
      });
    },
    getData() {
      api.supplierList().then((res) => {
        this.supplierList = res.rows;
      });
      api.getcountryAllList().then((res) => {
        this.countryList = res.data;
      });
      api.transferType().then((res) => {
        this.transList = res.data;
      });
      api.corpList().then((res) => {
        this.corpList = res.rows;
      });
      api.getOrderStatus().then((res) => {
        this.orderStatusList = res.data;
      });
      // man.userAll().then((res) => {
      //   this.userAllList = res.data
      // })
    },
    reset() {
      this.select = {};
      this.orderDate = [];
      this.getDataList();
      // this.creationTime = []
      // this.creationTime1 = []
    },
    getTime(val) {
      this.select.startDate = val ? val[0] : "";
      this.select.endDate = val ? val[1] : "";
    },
    // 点击修改
    toFixed(row) {
      api.transListDetail(row.pkId).then((res) => {
        row.scmReturnbVoList = res.rows;
        this.$router.push({
          path: "inOrOutDetails",
          query: {
            data: JSON.stringify([row]),
          },
        });
      });
    },
    selectRow(row) {
      this.loading2 = true
      api.transListDetail(row.pkId).then((res) => {
        this.tableDataDetails = res.rows;
        this.loading2 = false
      });
    },
    // 删除
    handleDelete(id) {
      this.$confirm('确认删除?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: "warning",
      }).then(() => {
        api.transDel(id).then((res) => {
          this.getDataList();
        });
      });
    },
    openDig() {
      this.$router.push({
        path: "inOrOutDetails",
      });
    },
    getDataList() {
      this.loading = true;
      this.loading2 = true
      api
        .transList(Object.assign({}, this.queryParams, this.select))
        .then((res) => {
          this.loading = false;
          this.tableData = res.rows;
          // this.tableDataDetails = res.rows[0].transferOrderItemsList
          this.total = res.total;
          if (res.rows.length > 0) {
            api.transListDetail(this.tableData[0].pkId).then((res) => {
              this.loading2 = false
              this.tableDataDetails = res.rows;
            });
          } else {
            this.tableDataDetails = [];
          }
        });
    },
    handleSelectionChange(val) {
      this.selRow = val;
    },
    handleSelectionChange1(val) {},
    tableRowClassName({ row, rowIndex }) {
      if (rowIndex % 2 == 1) {
        return "warning-row";
      } else if (rowIndex % 2 == 0) {
        return "success-row";
      }
      return "";
    },
  },
};
</script>
<style scoped lang="scss">
::v-deep .el-table .warning-row {
  background: #f9f9f9;
}

::v-deep .el-table .success-row {
  background: #ffffff;
}
::v-deep .el-table thead {
  color: #000000;
}
::v-deep .el-select {
  width: 100%;
}
.uploadIcon ::v-deep .el-upload--picture-card {
  display: none !important; /* 上传按钮隐藏 */
}
.page {
  padding: 20px;
  background: #f9f9f9;
  font-size: 14px;
  .main {
    background: #ffffff;
    border-radius: 8px;
    box-shadow: 0px 2px 20px 0px rgba(238, 238, 238, 0.5);
    .form_all {
      padding: 0px 20px 0 20px;
      // margin-bottom: 20px;
      background: #fff;
      border-radius: 8px;
    }
    .maintop {
      display: flex;
      padding: 0px 0px;
      justify-content: space-between;
      align-items: center;

      background: #f8f8f8;
      .mainbtn {
        .thebtn1 {
          background: #3181e5;
          color: #ffffff;
        }
        .thebtn2 {
          background: #ffad41;
          color: #ffffff;
        }
      }
      .maintitle {
        font-size: 10px;
        font-family: MicrosoftYaHei;
        color: #999999;
      }
    }
  }
  .tem {
    display: flex;
    align-items: center;
    justify-content: center;
    img {
      width: 28px;
      height: 20px;
      margin-right: 3px;
    }
  }
  .isRed {
    color: #ed1d25;
  }
  .isGreen {
    color: #1ab62b;
  }
  .bgImg {
    width: 48px;
    height: 48px;
  }
}
.openClose {
  text-align: right;
  margin-right: 10px;
  color: #3181e5;
}
.dizhi {
  ::v-deep .el-cascader {
    width: 100%;
  }
}
::v-deep .el-date-editor.el-input,
.el-date-editor.el-input__inner {
  width: auto;
}
</style>
